﻿/*
 *
 *
 *    ConfigUtils.cs
 *
 *    License: GNU General Public License Version 3.0.
 *    
 *    Copyright (C) 2017 by Matthew K. Roberts, KK5JY. All rights reserved.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *    
 *    This program is distributed in the hope that it will be useful, but
 *    WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    General Public License for more details.
 *    
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see: http://www.gnu.org/licenses/
 *    
 *
 */

using KK5JY.Config;
using System;
using Gdk;
using Pango;
using System.IO;

namespace KK5JY.Config {
	/// <summary>
	/// Extensions and utilities for configuration file management.
	/// </summary>
	public static class ConfigUtils {
		#region Font Conversion
		/// <summary>
		/// Read fields from a font object.
		/// </summary>
		public static void FromFont(this SerializableFont sf, FontDescription f) {
			sf.FontFamily = f.Family;
			//sf.GraphicsUnit = f.Unit.ToString();
			sf.Size = f.Size / 1024; // pango-to-device conversion
			sf.Style = f.Style.ToString();
		}

		/// <summary>
		/// Create a SerializableFont from a Drawing.Font.
		/// </summary>
		public static SerializableFont CreateSerializableFont(FontDescription f) {
			var result = new SerializableFont();
			result.FromFont(f);
			return result;
		}

		/// <summary>
		/// Render to Drawing.Font structure.
		/// </summary>
		public static FontDescription ToFont(this SerializableFont sf) {
			var result = new FontDescription {
				Family = sf.FontFamily,
				Style = (Pango.Style)(Enum.Parse(typeof(Pango.Style), sf.Style)),
				Size = Convert.ToInt32(sf.Size * 1024) // device to pango units
			};
			return result;
		}
		#endregion

		#region Color Conversion
		/// <summary>
		/// Copy ctor.
		/// </summary>
		public static void FromColor(this SerializableColor sc, Gdk.Color c) {
			sc.R = c.Red;
			sc.G = c.Green;
			sc.B = c.Blue;
		}

		/// <summary>
		/// Convert a Drawing.Color structure.
		/// </summary>
		public static SerializableColor CreateSerializableColor(Gdk.Color c) {
			return new SerializableColor {
				R = c.Red,
				G = c.Green,
				B = c.Blue
			};
		}

		/// <summary>
		/// Render to a Drawing.Color structure.
		/// </summary>
		public static Gdk.Color ToColor(this SerializableColor sc) {
			return new Gdk.Color(
				Convert.ToByte(sc.R / 256),
				Convert.ToByte(sc.G / 256),
				Convert.ToByte(sc.B / 256)
			);
		}
		#endregion	

		#region OS Utilities
		/// <summary>
		/// Returns true if running on Windows.
		/// </summary>
		public static bool IsWindows {
			get {
				// imprecise, but functional
				var x86 = System.Environment.GetFolderPath(Environment.SpecialFolder.SystemX86);
				return (
					(Path.DirectorySeparatorChar == '\\') &&
					(!String.IsNullOrEmpty(x86)) &&
					x86.Contains(":")
				);
			}
		}
		#endregion
	}
}
