﻿/*
 *
 *
 *    FilteredEntry.cs
 *
 *    License: GNU General Public License Version 3.0.
 *    
 *    Copyright (C) 2017 by Matthew K. Roberts, KK5JY. All rights reserved.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *    
 *    This program is distributed in the hope that it will be useful, but
 *    WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    General Public License for more details.
 *    
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see: http://www.gnu.org/licenses/
 *    
 *
 */

using System;
using System.Text;
using Gtk;

namespace KK5JY.SMI.GTK {
	/// <summary>
	/// A request event for text insertion.
	/// </summary>
	public sealed class FilteredEntryInsertRequestEvent : EventArgs {
		/// <summary>
		/// The text to insert.
		/// </summary>
		public string Text { get; set; }

		/// <summary>
		/// The insertion position.
		/// </summary>
		public int Position { get; set; }
	}

	/// <summary>
	/// A filtered Entry box.
	/// </summary>
	public sealed class FilteredEntry : Entry {
		/// <summary>
		/// Raised when text is to be inserted, to allow handlers to modify the text.
		/// </summary>
		public event EventHandler<FilteredEntryInsertRequestEvent> InsertRequest;

		/// <summary>
		/// Construct a new <c>FilteredEntry</c> widget.
		/// </summary>
		public FilteredEntry() {
			// nop
		}

		/// <summary>
		/// Raised when text insertion is attempted.
		/// </summary>
		protected override void OnTextInserted(string text, ref int position) {
			if (this.InsertRequest != null) {
				// ask the event handlers for modifications to the text
				var evOut = new FilteredEntryInsertRequestEvent { Text = text, Position = position };
				this.InsertRequest(this, evOut);
				if (String.IsNullOrEmpty(evOut.Text))
					return;

				// save the new values
				text = evOut.Text;
				if (position != evOut.Position)
					position = evOut.Position;
			}

			// chain to the base handler
			base.OnTextInserted(text, ref position);
		}
	}
}
