﻿/*
 *
 *
 *    MacroEditor.cs
 *
 *    License: GNU General Public License Version 3.0.
 *    
 *    Copyright (C) 2017 by Matthew K. Roberts, KK5JY. All rights reserved.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *    
 *    This program is distributed in the hope that it will be useful, but
 *    WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    General Public License for more details.
 *    
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see: http://www.gnu.org/licenses/
 *    
 *
 */

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using Gtk;

namespace KK5JY.SMI.GTK {
	/// <summary>
	/// An editor for macros.
	/// </summary>
	public sealed class MacroEditor : Dialog {
		#region Private Fields
		private TextView eText;
		private Entry eLabel;
		#endregion

		#region Public Properties
		/// <summary>
		/// The macro label.
		/// </summary>
		public string MacroLabel {
			get { return eLabel.Text; }
			set { eLabel.Text = value; }
		}

		/// <summary>
		/// The macro text.
		/// </summary>
		public string MacroText {
			get { return eText.Buffer.Text; }
			set { eText.Buffer.Text = value; }
		}

		/// <summary>
		/// Text item foreground color.
		/// </summary>
		public Gdk.Color Foreground {
			get { return eText.Style.Text(StateType.Normal); }
			set {
				eText.ModifyText(StateType.Normal, value);
				eLabel.ModifyText(StateType.Normal, value);
			}
		}

		/// <summary>
		/// Text item background color.
		/// </summary>
		public Gdk.Color Background {
			get { return eText.Style.Base(StateType.Normal); }
			set {
				eText.ModifyBase(StateType.Normal, value);
				eLabel.ModifyBase(StateType.Normal, value);
			}
		}
		#endregion

		#region Constructors
		/// <summary>
		/// Create a new macro editor.
		/// </summary>
		public MacroEditor(Window parent)
			: base("Edit Macro", parent, Gtk.DialogFlags.DestroyWithParent) {
			// configure the window itself
			this.Deletable = true;
			this.Resizable = true;
			this.Modal = true;
			this.SetSizeRequest(400, 300);

			// first row
			eText = new TextView();
			eText.AcceptsTab = false;
			this.VBox.PackStart(eText, true, true, 2);

			// second row
			var hbox = new HBox();
			this.VBox.PackStart(hbox, false, true, 2);
			var label = new Label("Button Label:");
			label.SetAlignment(0.95f, 0.5f);
			hbox.PackStart(label, false, true, 2);
			eLabel = new Entry();
			hbox.PackStart(eLabel, true, true, 2);

			foreach (var item in new Widget[] { eText, label, eLabel }) {
				var newFont = item.Style.FontDesc.Copy();
				newFont.Size = 12 * 1024;
				item.ModifyFont(newFont);
			}

			this.AddButton("OK", ResponseType.Ok);
			this.AddButton("Cancel", ResponseType.Cancel);

			this.SetResponseSensitive(ResponseType.Ok, true);
			this.SetResponseSensitive(ResponseType.Cancel, true);
			this.DefaultResponse = ResponseType.Ok;

			ShowAll();
		}
		#endregion
	}
}
