﻿/*
 *
 *
 *    Config.cs
 *
 *    License: GNU General Public License Version 3.0.
 *    
 *    Copyright (C) 2017 by Matthew K. Roberts, KK5JY. All rights reserved.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *    
 *    This program is distributed in the hope that it will be useful, but
 *    WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    General Public License for more details.
 *    
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see: http://www.gnu.org/licenses/
 *    
 *
 */

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using KK5JY.Config;
using System.Xml.Serialization;

namespace KK5JY.SMI {
	/// <summary>
	/// Data structure for macro definition.
	/// </summary>
	public class Macro {
		/// <summary>
		/// The macro definition string.
		/// </summary>
		public string Text { get; set; }

		/// <summary>
		/// The macro label.
		/// </summary>
		public string Label { get; set; }
	};

	/// <summary>
	/// The application config block.
	/// </summary>
	public class Config {
		#region Core Configuration
		/// <summary>
		/// Station call.
		/// </summary>
		public string MyCall { get; set; }

		/// <summary>
		/// Serial port.
		/// </summary>
		public string Port { get; set; }

		/// <summary>
		/// Serial speed.
		/// </summary>
		public uint Speed { get; set; }

		/// <summary>
		/// List of macro defintions.
		/// </summary>
		public Macro[] Macros { get; set; }
		#endregion

		#region GUI Configuration
		/// <summary>
		/// The TX exchange text.
		/// </summary>
		public string TxText { get; set; }

		/// <summary>
		/// The most recent log path.
		/// </summary>
		public string LastLogPath { get; set; }

		/// <summary>
		/// Path to the preferred logger.
		/// </summary>
		public string LoggerPath { get; set; }

		/// <summary>
		/// The main window font.
		/// </summary>
		public SerializableFont WindowFont { get; set; }

		/// <summary>
		/// The main window foreground color.
		/// </summary>
		public SerializableColor WindowForeground { get; set; }

		/// <summary>
		/// The main window background color.
		/// </summary>
		public SerializableColor WindowBackground { get; set; }

		/// <summary>
		/// Color representing normal operation.
		/// </summary>
		public SerializableColor GoodColor { get; set; }

		/// <summary>
		/// Color representing abnormal operation.
		/// </summary>
		public SerializableColor WarnColor { get; set; }

		/// <summary>
		/// Settings that should be available in the primary interface.
		/// </summary>
		public string[] ShortcutSettings { get; set; }

		/// <summary>
		/// Set to true iff the dupe checks should include frequency/band information.
		/// </summary>
		public bool DupeCheckIncludesBand { get; set; }

		/// <summary>
		/// The number of macro buttons to show.
		/// </summary>
		public UInt16 MacroButtonCount { get; set; }

		/// <summary>
		/// Set to true if log Entry fields should have their current text selected when the Entry is entered.
		/// </summary>
		public bool SelectLogTextOnEntry { get; set; }
		#endregion

		/// <summary>
		/// The XML version string.
		/// </summary>
		[XmlAttribute]
		public string Version {
			get { return "1.2"; }
			set { }
		}

		/// <summary>
		/// Ctor.
		/// </summary>
		public Config() {
			MyCall = "N0CALL";
			Port = "";
			Speed = 9600;
			DupeCheckIncludesBand = true;
			MacroButtonCount = 12;
			SelectLogTextOnEntry = true;
		}
	}
}
